@@ -1,6 +1,6 @@
 package App::tracepm::Tracer;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # saving CORE::GLOBAL::require doesn't work
 my $orig_require;
@@ -26,17 +26,20 @@ sub import {
     #$orig_require = \&CORE::GLOBAL::require;
     *CORE::GLOBAL::require = sub {
         my ($arg) = @_;
+        my $caller = caller;
         if ($INC{$arg}) {
             if ($opts->{workaround_log4perl}) {
                 # Log4perl <= 1.43 still does 'eval "require $foo" or ...'
                 # instead of 'eval "require $foo; 1" or ...' so running will
                 # fail. this workaround makes require() return 1.
-                my $caller = caller;
                 return 1 if $caller =~ /^Log::Log4perl/;
             }
             return 0;
         }
-        print $fh $arg, "\n" unless $arg =~ /\A\d/; # skip 'require 5.xxx'
+        unless ($arg =~ /\A\d/) { # skip 'require 5.xxx'
+            print $fh $arg, "\t", $caller, "\n";
+        }
+
         #$orig_require->($arg);
         CORE::require($arg);
     };
@@ -57,7 +60,7 @@ App::tracepm::Tracer - Trace module require to file
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 HOMEPAGE
 
